<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | Monitor Plugin 1.2                                                        |
// +---------------------------------------------------------------------------+
// | index.php                                                                 |
// |                                                                           |
// | Plugin administration page                                                |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2014 by the following authors:                              |
// |                                                                           |
// | Authors: Ben - ben AT geeklog DOT fr                                      |
// +---------------------------------------------------------------------------+
// | Created with the Geeklog Plugin Toolkit.                                  |
// +---------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

/**
* @package Monitor
*/
session_start();
$_SESSION['imgtoresize'] = 0;

require_once '../../../lib-common.php';
require_once '../../auth.inc.php';
require_once $_CONF['path_system'] . 'lib-user.php';

/**
* Upload new photo, delete old photo
*
* @param    string  $delete_photo   'on': delete old photo
* @return   string                  filename of new photo (empty = no new photo)
*
*/
function MONITOR_handlePhotoUpload ($delete_photo = '', $uid)
{
    global $_CONF, $_TABLES, $_USER, $LANG24;

    require_once ($_CONF['path_system'] . 'classes/upload.class.php');

    $upload = new upload();
	
    if (!empty ($_CONF['image_lib'])) {
        if ($_CONF['image_lib'] == 'imagemagick') {
            // Using imagemagick
            $upload->setMogrifyPath ($_CONF['path_to_mogrify']);
        } elseif ($_CONF['image_lib'] == 'netpbm') {
            // using netPBM
            $upload->setNetPBM ($_CONF['path_to_netpbm']);
        } elseif ($_CONF['image_lib'] == 'gdlib') {
            // using the GD library
            $upload->setGDLib ();
        }
        $upload->setAutomaticResize (true);
        if (isset ($_CONF['debug_image_upload']) &&
                $_CONF['debug_image_upload']) {
            $upload->setLogFile ($_CONF['path'] . 'logs/error.log');
            $upload->setDebug (true);
        }
        if (isset($_CONF['jpeg_quality'])) {
            $upload->setJpegQuality($_CONF['jpeg_quality']);
        }
    }
	
    $upload->setAllowedMimeTypes (array ('image/gif'   => '.gif',
                                         'image/jpeg'  => '.jpg,.jpeg',
                                         'image/pjpeg' => '.jpg,.jpeg',
                                         'image/x-png' => '.png',
                                         'image/png'   => '.png'
                                 )      );
    if (!$upload->setPath ($_CONF['path_images'] . 'userphotos')) {
        $display = COM_siteHeader ('menu', $LANG24[30]);
        $display .= COM_startBlock ($LANG24[30], '',
                COM_getBlockTemplate ('_msg_block', 'header'));
        $display .= $upload->printErrors (false);
        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block',
                                                        'footer'));
        $display .= COM_siteFooter ();
        COM_output($display);
        exit; // don't return
    }

    $filename = '';
    if (!empty ($delete_photo) && ($delete_photo == 'on')) {
        $delete_photo = true;
    } else {
        $delete_photo = false;
    }

    $curphoto = DB_getItem ($_TABLES['users'], 'photo',
                            "uid = {$uid}");
    if (empty ($curphoto)) {
        $delete_photo = false;
    }

    // see if user wants to upload a (new) photo
    $newphoto = $_FILES['photo'];
    if (!empty ($newphoto['name'])) {
        $pos = strrpos ($newphoto['name'], '.') + 1;
        $fextension = substr ($newphoto['name'], $pos);
		
		$username = DB_getItem ($_TABLES['users'], 'username',
                            "uid = {$uid}");
        $filename = $username . '.' . $fextension;

        if (!empty ($curphoto) && ($filename != $curphoto)) {
            $delete_photo = true;
        } else {
            $delete_photo = false;
        }
    }

    // delete old photo first
    if ($delete_photo) {
        USER_deletePhoto ($curphoto);
    }

    // now do the upload
    if (!empty ($filename)) {
        $upload->setFileNames ($filename);
        $upload->setPerms ('0644');
        if (($_CONF['max_photo_width'] > 0) &&
            ($_CONF['max_photo_height'] > 0)) {
            $upload->setMaxDimensions ($_CONF['max_photo_width'],
                                       $_CONF['max_photo_height']);
        } else {
            $upload->setMaxDimensions ($_CONF['max_image_width'],
                                       $_CONF['max_image_height']);
        }
        if ($_CONF['max_photo_size'] > 0) {
            $upload->setMaxFileSize($_CONF['max_photo_size']);
        } else {
            $upload->setMaxFileSize($_CONF['max_image_size']);
        }
        $upload->uploadFiles ();

        if ($upload->areErrors ()) {
            $display = COM_siteHeader ('menu', $LANG24[30]);
            $display .= COM_startBlock ($LANG24[30], '',
                    COM_getBlockTemplate ('_msg_block', 'header'));
            $display .= $upload->printErrors (false);
            $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block',
                                                            'footer'));
            $display .= COM_siteFooter ();
            COM_output($display);
            exit; // don't return
        }
    } else if (!$delete_photo && !empty ($curphoto)) {

		$filename = $curphoto;
    }

    return $filename;
}

/**
* Displays comments list
*
* @return   string          HTML for the list of items
*
*/
function MONITOR_commentsList()
{
    global $_CONF, $_TABLES, $LANG29, $LANG_ADMIN, $LANG_MONITOR_1, $_SCRIPTS;

    require_once $_CONF['path_system'] . 'lib-admin.php';

    $retval = '';
	
	$H = array($LANG29[14], $LANG29[10], $LANG29[36]);
	$section_title = $LANG_MONITOR_1['comments_list'];

	
	$sql = "SELECT cid AS id,date,title,comment,uid,type,sid "
		  . "FROM {$_TABLES['comments']} ";

    $query_arr = array(
        //'table'          => 'comments',
        'sql'            => $sql,
        //'query_fields'   => array('clid', 'created', 'title', 'owner_id'),
        'default_filter' => COM_getPermSQL ('AND', 0, 3)
    );

    $header_arr = array(      // display 'text' and use table field 'field'
        array('text' => $LANG_ADMIN['edit'], 'field' => 0),
        array('text' => $H[0], 'field' => 1, 'sort' => true),
        array('text' => $H[1], 'field' => 2),
        array('text' => $H[2], 'field' => 3),
        array('text' => $LANG29[42], 'field' => 'uid', 'sort' => true),
    );

    $text_arr = array('has_menu' => false,
	                  'has_extras' => true,
                      'title'    => $section_title,
                      'no_data'  => $LANG29[39],
                      'form_url' => "{$_CONF['site_admin_url']}/plugins/monitor/index.php?action=comments_list"
    );
    $form_arr = array('bottom' => '', 'top' => '');

	$defsort_arr = array('field' => 'id', 'direction' => 'desc');
	
	$retval .= LB. '<style>.admin-list-field { vertical-align:top !important;} </style>' . LB;
	 
    $retval .= ADMIN_list('MONITOR_commentsList', 'MONITOR_commentsList_fields', $header_arr,
                                $text_arr, $query_arr, $defsort_arr, $filter = '', $extra = '',
            $options = '', $form_arr='', $showsearch = true);

    return $retval;
}

function MONITOR_commentsList_fields($fieldname, $fieldvalue, $A, $icon_arr)
{
    global $_CONF, $LANG_MONITOR_1;

    switch($fieldname) {
        case "edit":
		    $edit_url = $_CONF['site_url'] . '/comment.php'
                    . '?mode=edit&type=article&amp;cid=' . $A[0] . '&amp;sid='
                            . $A['sid'];
            $retval = COM_createLink($icon_arr['edit'], $edit_url);
            break;
        case "title":
            $url = $_CONF['site_url'] .
                                 '/index.php?mode=v&amp;ad=' . $A['clid'];
            $retval = COM_createLink($A['title'], $url);
            break;
		case "uid":
            if ($A['uid'] < 2) {
			    $retval = $LANG_MONITOR_1['anonymous'];
				break;
			}
			$uid_url = $_CONF['site_url'] .
                                 '/users.php?mode=profile&uid=' . $A['uid'];
            $retval = COM_createLink(COM_getDisplayName($fieldvalue), $uid_url);
            break;
        default:
            $retval = stripslashes($fieldvalue);
            break;
    }
    return $retval;
}

/**
* Displays items needing edition
*
* Displays the list of items from tables
*
* @param    string  $type   Type of object to build list for
* @return   string          HTML for the list of items
*
*/
function MONITOR_itemlist($type, $subtype = '')
{
    global $_CONF, $_TABLES, $LANG29, $LANG_ADMIN,$LANG_MONITOR_1;

    require_once $_CONF['path_system'] . 'lib-admin.php';

    $retval = '';

    if (empty($type)) {
        // something is terribly wrong, bail
        COM_errorLog("Type not set for items list in monitor plugin");
        return $retval;
    }

    $isplugin = false;

    if ($type == 'image') {
        
		$sql = "SELECT i.ai_sid, i.ai_img_num, i.ai_filename, s.date, s.uid, s.title, u.username "
              . "FROM {$_TABLES['article_images']} AS i"
			  . " LEFT JOIN {$_TABLES['stories']} AS s ON i.ai_sid=s.sid"
			  . " LEFT JOIN {$_TABLES['users']} AS u ON s.uid=u.uid WHERE 1=1";
			  
        
		$section_title = $LANG_MONITOR_1['images_list'];
		
		$form_url = "{$_CONF['site_admin_url']}/plugins/monitor/index.php?action=images";
		
		$defsort_arr = array('field'     => 'ai_filename',
                         'direction' => 'ASC');
						 
		$query_arr = array('table' => 'article_images',
                       'sql' => $sql,
                       'query_fields' => array('ai_sid', 'ai_img_num', 'ai_filename', 'date', 's.uid', 'title', 'username'),
                       'default_filter' => "");
		//Build header list
		$header_arr = array(      # display 'text' and use table field 'field'
						//array('text' => $LANG29[14], 'field' => 'date', 'sort' => true),
						array('text' => $LANG29[10], 'field' => 'ai_filename', 'sort' => true), 
						array('text' => $LANG29[42], 'field' => 'uid', 'sort' => true)
		);
		
		$text_arr = array('has_menu' => false,
                      'title'    => $section_title,
                      'no_data'  => $LANG29[39],
                      'form_url' => $form_url,
					  'has_extras' => true,
					  'inline'   => true
					);
    } else {
        $retval .= "Type $type not implemented in monitor plugin";
		COM_errorLog($retval);
		return $retval;
    }
    
	$retval .= LB. '<style>.admin-list-field { vertical-align:top !important;} </style>' . LB;
	$retval .= ADMIN_list('monitor', 'MONITOR_getListField_images', $header_arr,
                          $text_arr, $query_arr, $defsort_arr);

    return $retval;
}



function MONITOR_getListField_images ($fieldname, $fieldvalue, $A, $icon_arr) {

    global $_CONF;
	
	switch ($fieldname) {

		case 'date':
		    
			$retval = '<small style="white-space: nowrap;">#'. $A['cid'] . ' - ';
			$creation = COM_getUserDateTimeFormat(strtotime($fieldvalue));
			$retval .= $creation[0]. '</small>';
		    
			break;
		
		//Images
		case 'ai_filename':
		    
			if (!is_file($_CONF['path_images'] . 'articles/' . $fieldvalue)) {
			    $image = $_CONF['site_url'] . '/admin/plugins/monitor/images/unavailable.png';
			} else {
			    $image = $_CONF['site_url'] . '/images/articles/' . $A['ai_filename'];
			}
			$retval = '<div style="float:left;margin:10px 20px 10px 5px; "><a href="' . $_CONF['site_url'] . '/images/articles/' . $fieldvalue . '" target="_blank"><img src="' . $_CONF['site_url'] . '/admin/plugins/monitor/images.php?src=' . $image . '&amp;w=100&amp;h=100&amp;a=t" align="top" alt="' . stripslashes($fieldvalue) . '" /></a></div><p><strong>' . stripslashes($fieldvalue) . '</strong><br' . XHTML . '>';
			$retval .= '#'. $A['ai_img_num'] . ' ';
			$creation = COM_getUserDateTimeFormat(strtotime($A['date']));
		   $retval .= $creation[0]  . '<br' . XHTML . '><a href="' . $_CONF['site_url'] . '/article.php?story=' . $A['ai_sid']. '" target="_blank">' . stripslashes($A['title']) . '</a></p>';
			   
			break;
			
		case 'title_image' :
            
			$retval = stripslashes($fieldvalue);
			
			break;
			
		case 'uid':
		    
			if ($fieldvalue >= 2) {
			    $retval = COM_createLink($A['username'], $_CONF['site_url']
                    . '/users.php?mode=profile&amp;uid=' .  $A['uid']);
				 $retval = '<p style="white-space: nowrap;">' .  $retval . '</span></p>';
			} else {
				 $retval = '<p style="white-space: nowrap;">' .  $A['username'] . '</p>';
			} 
		    
			break;
			
	    default:
            
			$retval = stripslashes($fieldvalue);
            
			break;
    }
	
	return $retval;
}


$display = '';

// Ensure user even has the rights to access this page
if (! SEC_hasRights('monitor.admin')) {
    $display .= COM_siteHeader('menu', $MESSAGE[30])
             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
             . COM_siteFooter();

    // Log attempt to access.log
    COM_accessLog("User {$_USER['username']} tried to illegally access the Monitor plugin administration screen.");

    echo $display;
    exit;
}


$log = isset($_POST['log']) ? COM_applyFilter($_POST['log']) : '';
/*
* Main Function
*/

$content = '';

$display = COM_siteHeader('none');

//Menu
$display .= '<p><a href="' . $_CONF['site_admin_url'] . '/plugins/monitor/index.php">' . $LANG_MONITOR_1['home'] . '</a> 
			| <a href="' . $_CONF['site_admin_url'] . '/plugins/monitor/index.php?action=images">' . $LANG_MONITOR_1['images'] . '</a>
			| <a href="' . $_CONF['site_admin_url'] . '/plugins/monitor/index.php?action=resize_images">' . $LANG_MONITOR_1['resize'] . '</a>
			| <a href="' . $_CONF['site_admin_url'] . '/plugins/monitor/index.php?action=change_user_photo">' . $LANG_MONITOR_1['change_user_photo'] . '</a>
			| <a href="' . $_CONF['site_admin_url'] . '/plugins/monitor/index.php?action=comments_list">' . $LANG_MONITOR_1['comments'] . '</a>
			| <a href="#" onclick="document.monitor_conf_link.submit()">' . $LANG_MONITOR_1['configuration'] . "</a>
    <form name='monitor_conf_link' action='" . $_CONF['site_admin_url'] . "/configuration.php' method='POST'>
    <input type='hidden' name='conf_group' value='monitor'></form></p>'";

 
$T = new Template($_CONF['path'] . 'plugins/monitor/templates');
$T->set_file (array ('admin' => 'administration.thtml'));

$action = isset($_REQUEST['action']) ? COM_applyFilter($_REQUEST['action']) : '';

$uid = intval($_POST['uid']);

switch ($action) {
    
	case 'images' :
	    
		$content .= MONITOR_itemlist('image');
		
		break;
		
	case 'upload_user_photo' :
		
		//Get user info
		$result = DB_query("SELECT fullname,cookietimeout,email,homepage,sig,emailstories,about,location,pgpkey,photo,remoteservice FROM {$_TABLES['users']},{$_TABLES['userprefs']},{$_TABLES['userinfo']} WHERE {$_TABLES['users']}.uid = {$uid} AND {$_TABLES['userprefs']}.uid = {$uid} AND {$_TABLES['userinfo']}.uid = {$uid}");
		$A = DB_fetchArray ($result);
		
		$T->set_var('title', 'Upload new photo for user ' . $A['fullname'] . ' (' . $uid . ')' );
		
		$filename = MONITOR_handlePhotoUpload ('', $uid );
		
		if (!empty ($filename)) {
            if (!file_exists ($_CONF['path_images'] . 'userphotos/' . $filename)) {
                $filename = '';
            }
        }
		
		DB_query("UPDATE {$_TABLES['users']} SET photo='$filename' WHERE uid={$uid}");
		
		$content .= USER_getPhoto ($uid, $filename, $A['email'], -1);
		$content .= '<p>' . $filename . '</p>';
		
		break;
	
    case 'resize_images' :	
	
	    $content .= "<form method=\"post\" action=\"{$_CONF['site_admin_url']}/plugins/monitor/index.php?action=resize_image\">";
		
		//List images from images folder
		$images_files = MONITOR_recursiveFiles();
		$content .= '<h2>' . $LANG_MONITOR_1['images_folder'] . '</h2>';
		if ($_SESSION['imgtoresize'] > 0) {
			$content .= '<p>' . $LANG_MONITOR_1['resize_images_help'] . '</p>';
			$content .="<p>$images_files</p>";
			$content .= "<input type=\"submit\" name=\"action\" value=\"{$LANG_MONITOR_1['resize_images']}\">";
		} else {
			$content .= '<p>' . $LANG_MONITOR_1['no_images_to_resize'] . '</p>';
		}

		$content .= "</form>";
	    
		break;
		
	case 'change_user_photo' :
		
		//User id is set
		if ( $_CONF['allow_user_photo'] == 1 && $uid > 0 ) {
		
		    $username = DB_getItem ($_TABLES['users'], 'username',
                            "uid = {$uid}");
							
			if ($username == '') {
			    $T->set_var('title', 'Change photo of user ' . $A['fullname'] . ' (' . $uid . ')' );
				$content = 'This user does not exist';
			} else {
				//Get user info
				$result = DB_query("SELECT fullname,cookietimeout,email,homepage,sig,emailstories,about,location,pgpkey,photo,remoteservice FROM {$_TABLES['users']},{$_TABLES['userprefs']},{$_TABLES['userinfo']} WHERE {$_TABLES['users']}.uid = {$uid} AND {$_TABLES['userprefs']}.uid = {$uid} AND {$_TABLES['userinfo']}.uid = {$uid}");
				$A = DB_fetchArray ($result);
				
				$T->set_var('title', 'Change photo of user ' . $A['fullname'] . ' (' . $uid . ')' );
				
				$photo = USER_getPhoto ($uid, $A['photo'], $A['email'], -1);
				
				if (empty ($photo)) {
					$display_photo = '';
				} else {
					$display_photo = '<br' . XHTML . '>' . $photo;
				}
				
				if (empty($_CONF['image_lib'])) {
					$scaling = $LANG04[162];
				} else {
					$scaling = $LANG04[161];
				}
				
				$photo_max_dimensions =	sprintf($LANG04[160],
							$_CONF['max_photo_width'], $_CONF['max_photo_height'],
							$_CONF['max_photo_size'], $scaling);
				
				//Form for new photo
				$content .= "<form method=\"post\" action=\"{$_CONF['site_admin_url']}/plugins/monitor/index.php\" enctype=\"multipart/form-data\">";
				$content .= '<p>' . $display_photo . '</p><p>' . $photo_max_dimensions . '</p>';
				$content .= '<p><input type="file" dir="ltr" id="photo" name="photo" size="30"' . XHTML .'></p>';
				$content .= "<input type=\"hidden\" name=\"action\" value=\"upload_user_photo\">";
				$content .= "<input type=\"hidden\" name=\"uid\" value=\"{$uid}\">";
				$content .= "<p><input type=\"submit\" value=\"Upload\"></p>";
				$content .= "</form>";
		    }
		} else {
			
			//Form for user id
		    $T->set_var(array(
			    'title'        => 'Select user id',
		    ));
		
			$content .= "<form method=\"post\" action=\"{$_CONF['site_admin_url']}/plugins/monitor/index.php\">";
			$content .= "User uid: <input type=\"text\" name=\"uid\" value=\"\">";
			$content .= "<input type=\"hidden\" name=\"action\" value=\"change_user_photo\">";
			$content .= "<input type=\"submit\" value=\"Go\">";
			$content .= "</form>";
			}
		break;
	
	case 'comments_list' :
	    
		$content .= MONITOR_commentsList();
		break;
		
	default:
	
		$T->set_var(array(
			'title'        => $LANG_MONITOR_1['view_clear_logs'],
		));
		
		$content .= "<form method=\"post\" action=\"{$_CONF['site_admin_url']}/plugins/monitor/index.php\">";
		$content .= "<p>{$LANG_MONITOR_1['file']}&nbsp;&nbsp;&nbsp;";
		$files = array();
		if ($dir = @opendir($_CONF['path_log'])) {
			while(($file = readdir($dir)) !== false) {
				if (is_file($_CONF['path_log'] . $file)) { array_push($files,$file); }
			}
			closedir($dir);
		}
		$content .= '<SELECT name="log">';
		if (empty($log)) { $log = $files[0]; } // default file to show
		for ($i = 0; $i < count($files); $i++) {
			$content .= '<option value="' . $files[$i] . '"';
			if ($log == $files[$i]) { $content .= ' SELECTED'; }
			$content .= '>' . $files[$i] . '</option>';
			next($files);
		}
		$content .= "</SELECT>&nbsp;&nbsp;&nbsp;&nbsp;";
		$content .= "<input type=\"submit\" name=\"action\" value=\"{$LANG_MONITOR_1['view_logs']}\">";
		$content .= "&nbsp;&nbsp;&nbsp;&nbsp;";
		$content .= "<input type=\"submit\" name=\"action\" value=\"{$LANG_MONITOR_1['clear_logs']}\"></p>";
		$content .= "</form>";
		
		if ($action == $LANG_MONITOR_1['clear_logs']) {
			unlink($_CONF['path_log'] . $_POST['log']);
			$timestamp = strftime( "%c" );
			$fd = fopen( $_CONF['path_log'] . $_POST['log'], a );
			fputs( $fd, "$timestamp - Log File Cleared \n" );
			fclose($fd);
			$action = $LANG_MONITOR_1['clear_logs'];
		}

		if ($action == $LANG_MONITOR_1['view_logs']) {
			$content .= "<hr><p><b>{$LANG_MONITOR_1['log_file']} " . $_POST['log'] . "</b></p><pre>";
			$content .= implode('', file($_CONF['path_log'] . $_POST['log']));
			$content .= "</pre>";
		}
		
		break;
}

$T->set_var(array(
    'admin_body'    => $content
));

$T->parse('output', 'admin');
$display .= $T->finish($T->get_var('output'));

$display .= COM_siteFooter();

COM_output ($display);

?>
